from osv import osv, fields

from tools import config
from tools.translate import _

class pm_base_contact_res_partner_contact(osv.osv):
	_inherit = 'res.partner.contact'

	def search(self, cr, uid, domain, offset=0, limit=None, order=None, context=None, count=False):
		address_id = context.get('address_id', False) or False
		partner_id = context.get('partner_id', False) or False

		if address_id:
			cr.execute(
				'SELECT contact.id FROM res_partner_contact contact, res_partner_job job '
				'WHERE contact.id = job.contact_id AND job.address_id = %s', (address_id, )
			)
			return [x[0] for x in cr.fetchall()]
		elif partner_id:
			cr.execute(
			""" SELECT DISTINCT job.contact_id
				  FROM res_partner_job job, res_partner_address addr
				 WHERE job.address_id = addr.id
				   AND addr.partner_id = %s
			""" % (partner_id))

			ret = [x[0] for x in cr.fetchall()]
			if not domain:
				return ret
			else:
				domain.append(('id','in',ret))

		return super(pm_base_contact_res_partner_contact, self).search(cr, uid, domain, offset=offset,
							limit=limit, order=order,
							context=context, count=count)

pm_base_contact_res_partner_contact()


class pm_base_contact_crm_case(osv.osv):
	_inherit = 'crm.case'

	_columns = {
		'partner_contact_id'	: fields.many2one('res.partner.contact', 'Contact'),
		'partner_address_id'	: fields.many2one('res.partner.address', 'Address', domain="[('partner_id','=',partner_id)]"),
	}

	def get_email(self, cr, uid, partner, contact):
		email = ''
		if contact:
			for func in contact.job_ids:
				if func.name.id == partner:
					return func.email
			if not email and contact.email:
				return contact.email
		addrs = self.pool.get('res.partner').browse(cr, uid, [partner])[0].address
		for addr in addrs:
			if addr.email:
				return addr.email
		return email

	def onchange_partner_id(self, cr, uid, ids, part, email=False, partner_contact_id=False):
		res = super(pm_base_contact_crm_case,self).onchange_partner_id(cr, uid, ids, part, email)
		addr = res['value']['partner_address_id']
		res['value']['partner_contact_id'] = partner_contact_id
		if addr:
			partner_address = self.pool.get('res.partner.address').browse(cr,uid,addr)
			if partner_address.job_ids:
				if partner_address.job_ids[0].contact_id:
					res['value']['partner_contact_id'] = partner_address.job_ids[0].contact_id.id
					contact = partner_address.job_ids[0].contact_id
			res['value']['email_from'] = self.get_email(cr,uid,part,contact)
		return res

	def on_change_partner_contact_id(self, cr, uid, ids, partner_id,partner_address_id,partner_contact_id, context=None):
		res = {}
		if not partner_contact_id:
			res['partner_address_id'] = ''
			res['partner_id'] = ''
		else:
			contact = self.pool.get('res.partner.contact').browse(cr, uid, [partner_contact_id])[0]
			if not partner_address_id and contact and contact.job_ids and contact.job_ids[0].address_id:
				res['partner_address_id'] = contact.job_ids[0].address_id.id
			if not partner_id and contact and contact.job_ids and contact.job_ids[0].address_id and contact.job_ids[0].address_id.partner_id:
				res['partner_id'] = contact.job_ids[0].address_id.partner_id.id
			res['email_from'] = self.get_email(cr,uid,( 'partner_id' in res ) and res['partner_id'] or partner_id,contact)

		return {'value' : res}

pm_base_contact_crm_case()



class pm_base_contact_sale_order(osv.osv):
	'''
	heritage de sale.order pour ajouter contact
	'''

	_name = 'sale.order'
	_inherit = 'sale.order'
	_description = 'Ajout contact sale.order'
	
	def onchange_sale_contact_id(self, cr, uid, ids, contact_id, partner_id, context=None):
		contact = self.pool.get('res.partner.contact').browse(cr, uid, [contact_id])[0]
		result = {}
		if contact.job_ids:
			if partner_id:
				for job in contact.job_ids:
					if job.address_id and job.address_id.partner_id and job.address_id.partner_id.id == partner_id:
						result['partner_order_id'] =  job.address_id.id
			else:
				adr = contact.job_ids[0].address_id
				if adr:
					result['partner_order_id'] =  adr.id
					if adr.partner_id:
						result['partner_id'] =  adr.partner_id.id
		return {'value' : result}

	_columns = {
		'sale_contact_id' : fields.many2one('res.partner.contact', 'Contact'),
	}
pm_base_contact_sale_order()


class pm_base_contact_purchase_order(osv.osv):
	'''
	heritage de purchase.order pour ajouter contact
	'''

	_name = 'purchase.order'
	_inherit = 'purchase.order'
	_description = 'Ajout contact purchase.order'

	def onchange_purchase_contact_id(self, cr, uid, ids, contact_id, partner_id, context=None):
		contact = self.pool.get('res.partner.contact').browse(cr, uid, [contact_id])[0]
		result = {}
		if contact.job_ids:
			if partner_id:
				for job in contact.job_ids:
					if job.address_id and job.address_id.partner_id and job.address_id.partner_id.id == partner_id:
						result['partner_address_id'] =  job.address_id.id
			else:
				adr = contact.job_ids[0].address_id
				if adr:
					result['partner_address_id'] =  adr.id
					if adr.partner_id:
						result['partner_id'] =  adr.partner_id.id
		return {'value' : result}

	_columns = {
		'purchase_contact_id' : fields.many2one('res.partner.contact', 'Contact'),
	}

pm_base_contact_purchase_order()









